@@ -68,6 +68,7 @@ import com.clustercontrol.preference.ClusterControlCorePreferencePage;
  */
 public class LoginManager {
     public static final String KEY_EJB_URL = "ejbUrl";
+    public static final String KEY_EJB_URL_NUM = "numOfUrlHistory";
     public static final String VALUE_EJB_URL = "jnp://localhost:1099";
     public static final String KEY_EJB_UID = "ejbUid";
     public static final String VALUE_EJB_UID = "hinemos";
@@ -168,14 +169,30 @@ public class LoginManager {
 			
 			//UIDと接続先をプレファレンスに書き戻す。			
 	        //セッションに接続先URLを格納
-			
 	        IPreferenceStore store = ClusterControlPlugin.getDefault()
                       .getPreferenceStore();
-	        store.setValue(ClusterControlCorePreferencePage.EJB_URL,url);
+        	store.setValue(ClusterControlCorePreferencePage.EJB_URL,url);
 	        store.setValue(ClusterControlCorePreferencePage.EJB_UID,uid);
+
+	        //今回の接続先URLがURL履歴に存在するかチェックする。
+	        int numOfUrlHistory = store.getInt(LoginManager.KEY_EJB_URL_NUM);
+	        boolean urlExist = false;
+	        for(int i=0; i<numOfUrlHistory; i++){
+	        	String histUrl = store.getString(LoginManager.KEY_EJB_URL + "_" + i);
+	        	if(url.equals(histUrl)){
+	        		//TODO 存在する場合、対象のURLを履歴の先頭に移動させ、他のURLを一つずつ後方にずらす
+	        		urlExist = true;
+	        		break;
+	        	}
+	        }
+	        //存在しない場合、URL履歴の末尾に追加
+	        if(!urlExist && !url.equals("")){
+	        	store.setValue(LoginManager.KEY_EJB_URL + "_" + numOfUrlHistory ,url);
+	        	numOfUrlHistory++;
+	        	store.setValue(LoginManager.KEY_EJB_URL_NUM, numOfUrlHistory);
+	        }
 	        
-	        
-			// クライアント側で保持するローカル情報の削除処理
+	        // クライアント側で保持するローカル情報の削除処理
 			LocalSession.getLocalSession().clearSessionData();
 			// マネージャの死活監視開始
 			LocalSession.getLocalSession().startChecktask(getInterval());
