@@ -111,7 +111,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 
 		// 計算ロジック情報を登録
 		OperateCollectCalcMaster ope = new OperateCollectCalcMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -133,7 +149,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		//カテゴリ毎の収集方法定義を登録
 		OperateCollectCategoryCollectMaster ope = new OperateCollectCategoryCollectMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -155,7 +187,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集カテゴリ定義を登録
 		OperateCollectCategoryMaster ope = new OperateCollectCategoryMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -178,7 +226,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目毎の計算方法を登録
 		OperateCollectItemCalcMethodMaster ope = new OperateCollectItemCalcMethodMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 	
 	/**
@@ -199,7 +263,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 	
 		// 収集項目毎の計算方法を登録
 		OperateCollectItemCalcMethodMaster ope = new OperateCollectItemCalcMethodMaster();
-		return ope.addSql(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.addSql(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectItemCalcMethodMasterSql() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectItemCalcMethodMasterSql() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 	
 	/**
@@ -220,7 +300,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目コードを登録
 		OperateCollectItemCodeMaster ope = new OperateCollectItemCodeMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -242,7 +338,23 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集方法・プラットフォーム毎の収集項目を登録
 		OperateCollectPollingMaster ope = new OperateCollectPollingMaster();
-		return ope.add(data);
+		boolean ret = false;
+		
+		try{
+			ret = ope.add(data);
+		}catch(CreateException e){
+			m_log.warn("addCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("addCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -266,7 +378,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 
 		// 計算ロジック情報を削除
 		OperateCollectCalcMaster ope = new OperateCollectCalcMaster();
-		return ope.delete(calcMethod);
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(calcMethod);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteCollectCalcMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -289,7 +427,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 
 		// 計算ロジック情報を削除
 		OperateCollectCalcMaster ope = new OperateCollectCalcMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCalcMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCalcMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCalcMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteCollectCalcMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -313,7 +477,34 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		//カテゴリ毎の収集方法定義を削除
 		OperateCollectCategoryCollectMaster ope = new OperateCollectCategoryCollectMaster();
-		return ope.delete(pk);
+		
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(pk);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteCollectCategoryCollectMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -336,7 +527,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		//カテゴリ毎の収集方法定義を削除
 		OperateCollectCategoryCollectMaster ope = new OperateCollectCategoryCollectMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCategoryCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCategoryCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCategoryCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteCollectCategoryCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -360,7 +577,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集カテゴリ定義を削除
 		OperateCollectCategoryMaster ope = new OperateCollectCategoryMaster();
-		return ope.delete(categoryCode);
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(categoryCode);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectCategoryMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -383,7 +626,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集カテゴリ定義を削除
 		OperateCollectCategoryMaster ope = new OperateCollectCategoryMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectCategoryMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectCategoryMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectCategoryMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectCategoryMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -407,7 +676,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目毎の計算方法を削除
 		OperateCollectItemCalcMethodMaster ope = new OperateCollectItemCalcMethodMaster();
-		return ope.delete(pk);
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(pk);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectItemCalcMethodMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -430,7 +725,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目毎の計算方法を削除
 		OperateCollectItemCalcMethodMaster ope = new OperateCollectItemCalcMethodMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectItemCalcMethodMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectItemCalcMethodMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectItemCalcMethodMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectItemCalcMethodMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -454,7 +775,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目コードを削除
 		OperateCollectItemCodeMaster ope = new OperateCollectItemCodeMaster();
-		return ope.delete(itemCode);
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(itemCode);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectItemCodeMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -478,7 +825,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		
 		// 収集項目コードを削除
 		OperateCollectItemCodeMaster ope = new OperateCollectItemCodeMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectItemCodeMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectItemCodeMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectItemCodeMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectItemCodeMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -502,7 +875,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 	
 		// 収集方法・プラットフォーム毎の収集項目を削除
 		OperateCollectPollingMaster ope = new OperateCollectPollingMaster();
-		return ope.delete(pk);
+		boolean ret = false;
+		
+		try{
+			ret = ope.delete(pk);
+		}catch(EJBException e){
+			m_log.warn("deleteCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectPollingMaster() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -525,7 +924,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 	
 		// 収集方法・プラットフォーム毎の収集項目を削除
 		OperateCollectPollingMaster ope = new OperateCollectPollingMaster();
-		return ope.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = ope.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectPollingMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectPollingMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectPollingMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectPollingMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
@@ -554,7 +979,33 @@ public abstract class PerformanceCollectMasterControllerBean implements SessionB
 		OperateCollectCategoryMaster opeCategory = new OperateCollectCategoryMaster();
 		OperateCollectCalcMaster opeCalc = new OperateCollectCalcMaster();
 		
-		return opeCategoryCollect.deleteAll() && opePolling.deleteAll() && opeItemCalc.deleteAll() && opeItemCode.deleteAll() && opeCategory.deleteAll() && opeCalc.deleteAll();
+		boolean ret = false;
+		
+		try{
+			ret = opeCategoryCollect.deleteAll() && opePolling.deleteAll() && opeItemCalc.deleteAll() && opeItemCode.deleteAll() && opeCategory.deleteAll() && opeCalc.deleteAll();
+		}catch(EJBException e){
+			m_log.warn("deleteCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NamingException e){
+			m_log.warn("deleteCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(FinderException e){
+			m_log.warn("deleteCollectMasterAll() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 		
 	}
 	
