@@ -40,6 +40,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.FacilityNotFoundException;
 import com.clustercontrol.JobInfoNotFoundException;
+import com.clustercontrol.bean.FacilityConstant;
 import com.clustercontrol.bean.JobConstant;
 import com.clustercontrol.bean.StatusConstant;
 import com.clustercontrol.commons.util.ConnectionManager;
@@ -805,10 +806,12 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 			sqlMaster.append("cc_job_mst.job_type, ");
 			sqlMaster.append("cc_job_command_mst.facility_id ");
 			sqlMaster.append("FROM cc_job_mst left join cc_job_command_mst ");
-			sqlMaster.append("on  (cc_job_mst.job_id=cc_job_command_mst.job_id) ");
+			sqlMaster.append("on (cc_job_mst.job_id=cc_job_command_mst.job_id AND cc_job_mst.jobunit_id=cc_job_command_mst.jobunit_id) ");
 			sqlMaster.append("WHERE  cc_job_mst.job_id= ? ");
 			sqlMaster.append("AND  cc_job_mst.jobunit_id= ? ");
 			
+			m_log.debug("makeSession() sqlMaster : sql=" + sqlMaster.toString());
+			
 			//SQL文のセット(マスタ検索)
 			stmtMasster = connMaster.prepareStatement(sqlMaster.toString());
 
@@ -855,8 +858,11 @@ public class JobSessionNodeDAOImpl implements JobSessionNodeDAO {
 						updateStmt.executeUpdate();
 						updateStmt.close();
 						
-						//ノードのファシリティIDリスト取得
-						ArrayList<String> nodeIdList = repository.getExecTargetFacilityIdList(facilityId);
+						ArrayList<String> nodeIdList = new ArrayList<String>();
+						if(facilityId != null){
+							//ノードのファシリティIDリスト取得
+							nodeIdList = repository.getExecTargetFacilityIdList(facilityId);
+						}
 //						ArrayList<String> nodeIdList = null;
 //						if(repository.isNode(facilityId)){
 //							//ファシリティIDがノードの場合
