@@ -166,22 +166,39 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 						tm.commit();
 					}
 			} catch (SecurityException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (SystemException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (NotSupportedException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (RollbackException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicMixedException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicRollbackException e) {
-				m_log.debug("addMaintenance() : " + e.getMessage());
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (HinemosUnknownException e) {
+				m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} finally {
 				if(tm.getTransaction() != null){
@@ -192,19 +209,29 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			}
 				
 		} catch (CreateException e) {
-			m_log.debug("addMaintenance() : " + e.getMessage());
+			m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (NamingException e) {
-			m_log.debug("addMaintenance() : " + e.getMessage());
+			m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (SchedulerException e) {
-			m_log.debug("addMaintenance() : " + e.getMessage());
+			m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (ParseException e) {
-			m_log.debug("addMaintenance() : " + e.getMessage());
+			m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (RemoteException e) {
-			m_log.debug("addMaintenance() : " + e.getMessage());
+			m_log.warn("addMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} finally {
 			
@@ -288,48 +315,104 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 						tm.commit();
 					}
 			} catch (SecurityException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (SystemException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (NotSupportedException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (RollbackException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicMixedException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicRollbackException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (CreateException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				e.printStackTrace();
 			} catch (RemoveException e) {
-				m_log.debug("modifyMaintenance() : " + e.getMessage());
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				e.printStackTrace();
+			} catch (NotifyNotFoundException e) {
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (HinemosUnknownException e) {
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (FinderException e) {
+				m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
 			} finally {
-				if(tm.getTransaction() != null){
-					if(!result){
-						tm.rollback();
+				try {
+					if(tm.getTransaction() != null){
+						if(!result){
+							tm.rollback();
+						}
 					}
+				} catch (IllegalStateException e) {
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
+				} catch (SecurityException e) {
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
+				} catch (SystemException e) {
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
 				}
 			}
 				
 		} catch (NamingException e) {
-			m_log.debug("modifyMaintenance() : " + e.getMessage());
+			m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (SchedulerException e) {
-			m_log.debug("modifyMaintenance() : " + e.getMessage());
+			m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (ParseException e) {
-			m_log.debug("modifyMaintenance() : " + e.getMessage());
+			m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (RemoteException e) {
-			m_log.debug("modifyMaintenance() : " + e.getMessage());
+			m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} finally {
 			
@@ -339,10 +422,19 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 					tm.resume(oldTx);
 				
 				} catch(InvalidTransactionException e){
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				} catch(IllegalStateException e){
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				} catch(SystemException e){
+					m_log.warn("modifyMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				}
 			}
@@ -412,45 +504,104 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 						tm.commit();
 					}
 			} catch (SecurityException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (SystemException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (NotSupportedException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (RollbackException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicMixedException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (HeuristicRollbackException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
 				throw e;
 			} catch (FinderException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
-					e.printStackTrace();
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				e.printStackTrace();
 			} catch (CreateException e) {
-				m_log.debug("deleteMaintenance() : " + e.getMessage());
-					e.printStackTrace();
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				e.printStackTrace();
+			} catch (EJBException e) {
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (NotifyNotFoundException e) {
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (HinemosUnknownException e) {
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
+			} catch (RemoveException e) {
+				m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage());
+				m_context.setRollbackOnly();
+				throw e;
 			} finally {
-				if(tm.getTransaction() != null){
-					if(!result){
-						tm.rollback();
+				try {
+					if(tm.getTransaction() != null){
+						if(!result){
+							tm.rollback();
+						}
 					}
+				} catch (IllegalStateException e) {
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
+				} catch (SecurityException e) {
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
+				} catch (SystemException e) {
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
+					throw e;
 				}
 			}
 				
 		} catch (NamingException e) {
-			m_log.debug("deleteMaintenance() : " + e.getMessage());
+			m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (SchedulerException e) {
-			m_log.debug("deleteMaintenance() : " + e.getMessage());
+			m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} catch (RemoteException e) {
-			m_log.debug("deleteMaintenance() : " + e.getMessage());
+			m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
 			throw e;
 		} finally {
 			
@@ -458,12 +609,20 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			if(oldTx != null){
 				try{
 					tm.resume(oldTx);
-				
 				} catch(InvalidTransactionException e){
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				} catch(IllegalStateException e){
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				} catch(SystemException e){
+					m_log.warn("deleteMaintenance() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage());
+					m_context.setRollbackOnly();
 					throw e;
 				}
 			}
@@ -499,10 +658,52 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
      *     
 	 */
-	public int deleteEventLog(String keep_id, boolean status) throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException {
+	public int deleteEventLog(String keep_id, boolean status)  throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException{
 		m_log.debug("deleteEventLog() : keep_id = " + keep_id + ", status = " + status);
 		MaintenanceEvent event = new MaintenanceEvent();
-		return event.delete(keep_id, status);
+		
+		int ret = 0;
+		
+		try{
+			ret = event.delete(keep_id, status);
+		}catch(NamingException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(CreateException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(SQLException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(HinemosUnknownException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NotifyNotFoundException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 
 	
@@ -534,7 +735,49 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteJobHistory(String keep_id, boolean status) throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException {
 		m_log.debug("deleteJobHistory() : keep_id = " + keep_id + ", status = " + status);
 		MaintenanceJob job = new MaintenanceJob();
-		return job.delete(keep_id, status);
+		
+		int ret = 0;
+		
+		try{
+			ret = job.delete(keep_id, status);
+		}catch(NamingException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(CreateException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(SQLException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(HinemosUnknownException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NotifyNotFoundException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 	
 	
@@ -564,10 +807,52 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
      *     
 	 */	
-	public int deleteCollectiveRunHistory(String keep_id, boolean status) throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException {
+	public int deleteCollectiveRunHistory(String keep_id, boolean status)  throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException{
 		m_log.debug("deleteCollectiveRunHistory() : keep_id = " + keep_id + ", status = " + status);
 		MaintenanceCrun crun = new MaintenanceCrun();
-		return crun.delete(keep_id, status);
+		
+		int ret = 0;
+		
+		try{
+			ret = crun.delete(keep_id, status);
+		}catch(NamingException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(CreateException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(SQLException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(HinemosUnknownException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NotifyNotFoundException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 	
 	/**
@@ -599,7 +884,49 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	public int deleteVmLog(String keep_id, boolean status) throws FinderException, NamingException, CreateException, SQLException, RemoveException, HinemosUnknownException, NotifyNotFoundException {
 		m_log.debug("deleteVmLog() : keep_id = " + keep_id + ", status = " + status);
 		MaintenanceVM vm = new MaintenanceVM();
-		return vm.delete(keep_id, status);
+		
+		int ret = 0;
+		
+		try{
+			ret = vm.delete(keep_id, status);
+		}catch(NamingException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(CreateException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(SQLException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(RemoveException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(HinemosUnknownException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}catch(NotifyNotFoundException e){
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (FinderException e) {
+			m_log.warn("deleteEventLog() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
+		
+		return ret;
 	}
 	
 	/**
@@ -627,21 +954,35 @@ public abstract class MaintenanceControllerBean implements SessionBean {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "004", args);
-            m_log.debug("addSchedule() : " + e.getMessage());
+			m_log.warn("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
         } catch (NamingException e) {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "004", args);
-            m_log.debug("addSchedule() : " + e.getMessage());
+			m_log.warn("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "004", args);
-            m_log.debug("addSchedule() : " + e.getMessage());
+			m_log.warn("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
-        }
+        } catch (RemoteException e) {
+            AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
+            String[] args = {info.getId()};
+            apllog.put("SYS", "004", args);
+			m_log.warn("addSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+            throw e;
+		}
 	}
 	
 	/**
@@ -656,7 +997,7 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
 	 * 
 	 */
-	public void modifySchedule(ScheduleInfo info) throws NamingException, SchedulerException, ParseException, RemoteException {
+	public void modifySchedule(ScheduleInfo info)  throws NamingException, SchedulerException, ParseException, RemoteException{
 	    m_log.debug("modifySchedule() : scheduleId=" + info.getId());
 	    
 	    Principal pri = m_context.getCallerPrincipal();
@@ -668,21 +1009,35 @@ public abstract class MaintenanceControllerBean implements SessionBean {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.debug("modifySchedule() : " + e.getMessage());
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.debug("modifySchedule() : " + e.getMessage());
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
         } catch (ParseException e) {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {info.getId()};
             apllog.put("SYS", "006", args);
-            m_log.debug("modifySchedule() : " + e.getMessage());
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
-        }
+        } catch (RemoteException e) {
+            AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
+            String[] args = {info.getId()};
+            apllog.put("SYS", "006", args);
+			m_log.warn("modifySchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+            throw e;
+		}
 		
 	}
 	
@@ -708,15 +1063,27 @@ public abstract class MaintenanceControllerBean implements SessionBean {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {scheduleId};
             apllog.put("SYS", "005", args);
-            m_log.debug("deleteSchedule() : " + e.getMessage());
+			m_log.warn("deleteSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
             throw e;
         } catch (SchedulerException e) {
             AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
             String[] args = {scheduleId};
             apllog.put("SYS", "005", args);
-            m_log.debug("deleteSchedule() : " + e.getMessage());
-            throw e;
-        }
+			m_log.warn("deleteSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+             throw e;
+        } catch (RemoteException e) {
+            AplLogger apllog = new AplLogger("MAINTENANCE", "maintenance");
+            String[] args = {scheduleId};
+            apllog.put("SYS", "005", args);
+			m_log.warn("deleteSchedule() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+             throw e;
+		}
 	}
 	
 	/**
@@ -956,14 +1323,30 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			//メンテナンス実行
 			runMaintenance(maintenanceId);
 		} catch (CreateException e) {
-			m_log.error("scheduleRunMaintainance " + e.getMessage(), e);
+			m_log.error("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
 		} catch (NamingException e) {
-			m_log.error("scheduleRunMaintainance " + e.getMessage(), e);
+			m_log.error("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
 		} catch (CalendarNotFountException e) {
-			m_log.error("scheduleRunMaintainance " + e.getMessage(), e);
+			m_log.error("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
+		} catch (HinemosUnknownException e) {
+			m_log.error("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (NotifyNotFoundException e) {
+			m_log.error("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
+			throw e;
 		}
 	}
 	
@@ -988,7 +1371,19 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 		m_log.debug("runMaintenance() : maintenanceId=" + maintenanceId);
 		
 		OperationMaintenance operation = new OperationMaintenance();
-		operation.runMaintenance(maintenanceId);
+		try {
+			operation.runMaintenance(maintenanceId);
+		} catch (HinemosUnknownException e) {
+			m_log.warn("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		} catch (NotifyNotFoundException e) {
+			m_log.warn("scheduleRunMaintainance() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+			throw e;
+		}
 	}
 	
 	
