@@ -150,10 +150,14 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			// 新規にマップを生成する
 			map = new NodeMapModel(parentFacilityId, facilityId, facilityName, facilityPath);
 		} catch (FinderException e) {
-			m_log.error(e.getMessage(), e);
+			m_log.error("createNodeMapModel() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			return new NodeMapModel("", "", "Could not create a map.", "-");
 		} catch (Exception e) {
-			m_log.error("CreateNodeMapModel " + e.getMessage(), e);
+			m_log.error("createNodeMapModel() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -187,15 +191,21 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				try {
 					((AssociationLocal)bean).remove();
 				} catch (EJBException e) {
-					m_log.error(e.getMessage(), e);
+					m_log.error("registerNodeMapModel() ((AssociationLocal)bean).remove() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				} catch (RemoveException e) {
-					m_log.error(e.getMessage(), e);
+					m_log.error("registerNodeMapModel() ((AssociationLocal)bean).remove() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				}
 			}
 		} catch (FinderException e) {
 			// 何もしない
 		} catch (Exception e) {
-			m_log.error("regiseterNodeMapModel " + e.getMessage(), e);
+			m_log.error("registerNodeMapModel() ((AssociationLocal)bean).remove() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -206,15 +216,21 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				try {
 					((FacilityPositionLocal)bean).remove();
 				} catch (EJBException e) {
-					m_log.error(e.getMessage(), e);
+					m_log.error("registerNodeMapModel() ((FacilityPositionLocal)bean).remove() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				} catch (RemoveException e) {
-					m_log.error(e.getMessage(), e);
+					m_log.error("registerNodeMapModel() ((FacilityPositionLocal)bean).remove() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				}
 			}
 		} catch (FinderException e) {
 			// 何もしない
 		} catch (Exception e) {
-			m_log.error("regiseterNodeMapModel " + e.getMessage(), e);
+			m_log.error("registerNodeMapModel() ((FacilityPositionLocal)bean).remove() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -230,12 +246,18 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 						map.getBgName()
 				);
 			} catch (CreateException e1) {
-				m_log.error(e,e);
+				m_log.error("registerNodeMapModel() MapInfoUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 			} catch (NamingException e1) {
-				m_log.error(e,e);
+				m_log.error("registerNodeMapModel() MapInfoUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 			}
 		} catch (Exception e) {
-			m_log.error("regiseterNodeMapModel " + e.getMessage(), e);
+			m_log.error("registerNodeMapModel() MapInfoUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 
@@ -258,13 +280,19 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 							elemet[i].getY()
 					);
 				} catch (CreateException e1) {
-					m_log.error(e,e);
+					m_log.error("registerNodeMapModel() FacilityPositionUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				} catch (Exception e1) {
-					m_log.error("regiseterNodeMapModel " + e1.getMessage(), e1);
+					m_log.error("registerNodeMapModel() FacilityPositionUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 					throw new HinemosUnknownException(e1.getMessage(), e1);
 				}
 			} catch (NamingException e) {
-				m_log.error(e,e);
+				m_log.error("registerNodeMapModel() FacilityPositionUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 			}
 		}
 
@@ -282,13 +310,19 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 							asso.getTarget()
 					);
 				} catch (CreateException e1) {
-					m_log.error(e,e);
+					m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 				} catch (Exception e1) {
-					m_log.error("regiseterNodeMapModel " + e1.getMessage(), e1);
+					m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+							", " + e.getMessage(), e);
+					m_context.setRollbackOnly();
 					throw new HinemosUnknownException(e1.getMessage(), e1);
 				}
 			} catch (NamingException e) {
-				m_log.error(e,e);
+				m_log.error("registerNodeMapModel() AssociationUtil.getLocalHome().create() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 			}
 		}
 		
@@ -307,7 +341,9 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 				// m_log.warn("registerNodeMapModel : FinderException, " + facilityId);
 				continue;
 			} catch (Exception e) {
-				m_log.error("regiseterNodeMapModel " + e.getMessage(), e);
+				m_log.error("registerNodeMapModel() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 				throw new HinemosUnknownException(e.getMessage(), e);
 			}
 			if (!iconImage.equals(bean.getIconImage())) {
@@ -515,11 +551,15 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			try {
 				BgImageUtil.getLocalHome().create(filename, filedata);
 			} catch (Exception e1) {
-				m_log.error("NamingException " + e1.getMessage(),e1);
+				m_log.error("setBgImage() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 				throw new HinemosUnknownException(e1.getMessage(),e1);
 			}
 		} catch (Exception e) {
-			m_log.error("NamingException " + e.getMessage(),e);
+			m_log.error("setBgImage() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
 		}
 	}
@@ -571,7 +611,9 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 		} catch (FinderException e) {
 			return false;
 		} catch (Exception e) {
-			m_log.error("isBgImage " + e.getMessage(),e);
+			m_log.error("isBgImage() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
 		}
 		return true;
@@ -636,11 +678,15 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 			try {
 				IconImageUtil.getLocalHome().create(filename, filedata);
 			} catch (Exception e1) {
-				m_log.error("setIconImage " + e1.getMessage(),e1);
+				m_log.error("setIconImage() : " + e.getClass().getSimpleName() +
+						", " + e.getMessage(), e);
+				m_context.setRollbackOnly();
 				throw new HinemosUnknownException(e1.getMessage(),e1);
 			}
 		} catch (Exception e) {
-			m_log.error("setIconImage " + e.getMessage(),e);
+			m_log.error("setIconImage() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(),e);
 		}
 	}
@@ -691,9 +737,15 @@ public abstract class NodeMapControllerBean implements javax.ejb.SessionBean {
 		try {
 			IconImageUtil.getLocalHome().findByPrimaryKey(filename);
 		} catch (FinderException e) {
+			m_log.warn("isIconImage() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage());
+			m_context.setRollbackOnly();
+
 			return false;
 		} catch (Exception e) {
-			m_log.error("isIconImage " + e.getMessage(), e);
+			m_log.error("isIconImage() : " + e.getClass().getSimpleName() +
+					", " + e.getMessage(), e);
+			m_context.setRollbackOnly();
 			throw new HinemosUnknownException(e.getMessage(), e);
 		}
 		return true;
