@@ -42,6 +42,7 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.FacilityNotFoundException;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.MonitorBlockConstant;
 import com.clustercontrol.bean.PingRunCountConstant;
 import com.clustercontrol.bean.PingRunIntervalConstant;
@@ -59,6 +60,7 @@ import com.clustercontrol.ping.util.ReachAddressFping;
 import com.clustercontrol.priority.util.PriorityJudgment;
 import com.clustercontrol.repository.bean.FacilityAttributeConstant;
 import com.clustercontrol.util.Messages;
+import com.clustercontrol.util.apllog.AplLogger;
 
 /**
  * ping監視を実行するクラス<BR>
@@ -389,18 +391,42 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		 * 重要度不明で通知する。
 		 */
 		
-		
 		/*
 		 * 取得結果の要素チェック
 		 */
 		Iterator<String> itr = messages.iterator();
+		m_log.debug("wrapUpFping(): start logic: " + messages.size());
 		while(itr.hasNext()) {
 			
 			message = itr.next();
+			m_log.debug("wrapUpFping(): checkpoint");
 			
 			//IPアドレスの形式が正しい場合は、処理を続行する
-			matcherIp = patternIp.matcher(message);
-			if(matcherIp.matches()){
+			boolean bValidIP = false;
+			if (version == 6)
+			{
+				m_log.debug("wrapUpFping(): into IPv6 loop");
+				String[] strs = message.split(" ");
+				try
+				{
+					InetAddress address = InetAddress.getByName(strs[0]);
+					bValidIP = true;
+				}
+				catch (Exception e)
+				{
+					m_log.error("wrapUpFping(): invalid IPv6 adress: original message: " + message);
+					m_log.error("wrapUpFping(): stack trace: " + e.getMessage());
+				}
+			}
+			else
+			{
+				matcherIp = patternIp.matcher(message);
+				if(matcherIp.matches())
+				{
+					bValidIP = true;
+				}
+			}
+			if(bValidIP){
 				
 				//各IPの結果を要素ごとに確認する
 				String[] strs = patternSp.split(message);
@@ -442,7 +468,9 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 		 * チェックした内容を結果としてまとめる
 		 */
 		itr = hostSet.iterator();
+		m_log.debug("wrapUpFping() : before into check result append loop");
 		while(itr.hasNext()) {
+			m_log.debug("wrapUpFping() : after into check result append loop");
 			
 			String host = itr.next();
 			String normalMessage = normalMap.get(host);
@@ -795,7 +823,7 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						if(m_nodeDate > m_scopeDate){
 							m_scopeDate = m_nodeDate;
 						}
-						
+
 						// ノードのログ出力情報を送信 
 						if(MonitorBlockConstant.TYPE_NODE == m_monitorBlock ||
 								(MonitorBlockConstant.TYPE_SCOPE == m_monitorBlock && m_isNode) || 
@@ -812,7 +840,6 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 				//   fpingを利用する場合には、ファシリティのリストを与えて一気にpingします。
 				boolean ret = collectFping(facilityList,priorityList);
 				
-				
 				if(ret){
 					Hashtable fpingResultSet = new Hashtable();
 					Hashtable fpingResultSetV6 = new Hashtable();
@@ -821,11 +848,14 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						fpingResultSet = wrapUpFping(m_MsgErr, m_runCount,4);
 					}
 					if(m_MsgErrV6 != null){
+						m_log.debug("runMonitorInfo(): fpingResultSetV6 check");
 						fpingResultSetV6 = wrapUpFping(m_MsgErrV6, m_runCount,6);
 					}
 					
 					//IPv4の情報が存在しない場合は、IPv6の情報で上書きする
+					m_log.debug("runMonitorInfo(): before fpingResultSet check");
 					if( fpingResultSet.size() == 0){
+						m_log.debug("runMonitorInfo(): after fpingResultSet check");
 						fpingResultSet = fpingResultSetV6;
 					}
 					//IPv4の情報が存在する場合は、IPv6の情報を追加する
@@ -849,12 +879,25 @@ public class RunMonitorPing extends RunMonitorNumericValueType {
 						
 						// ポーリングされていないノード(IPアドレス未記入のノード)を除く。
 						if(node != null) {
-							
+							m_log.debug("runMonitorInfo(): before fpingResultSet.get()");
 							nodeResult = (PingResult)fpingResultSet.get(node[0]);
 							
 							if(nodeResult ==null){
+								m_log.debug("runMonitorInfo(): after fpingResultSet.get()");
 								
 								/* fping失敗で結果がありません。*/
+								AplLogger apllog = new AplLogger(HinemosModuleConstant.MONITOR_PING, "ping");
+								String[] args = {m_monitorId};
+								String logMsg = "";
+								if (m_MsgErr != null)
+								{
+									logMsg = m_MsgErr.toString();
+								}
+								if (m_MsgErrV6 != null)
+								{
+									logMsg += " , " + m_MsgErrV6.toString();
+								}
+								apllog.put("SYS", "001", args,logMsg);
 								m_log.error("Fping no response.");
 								
 							}else{
