@@ -25,11 +25,10 @@ import com.clustercontrol.util.PropertyUtil;
 public class NodePropertyUtil {
 	
 	/** ----- 初期値キャッシュ ----- */
-	private static HashMap<Locale, HashMap<Integer, Property>> cachedInitProperty = null;
-	
-	static {
-		cachedInitProperty = new HashMap<Locale, HashMap<Integer, Property>>();
-	}
+	public static Object[][] platformCache = null;
+	public static Object[][] facilityIdCache = null;
+	public static Object[][] vmSolutionCache = null;
+	public static Object[][] vmProtocolCache = null;
 	
 	/**
 	 * PropertyクラスをNodeInfoクラスに変換するメソッド。
@@ -700,15 +699,6 @@ public class NodePropertyUtil {
 	 * @return ノード用プロパティ
 	 */
 	public static Property getProperty(int mode, Locale locale) {
-		// 初期値のキャッシュが存在すれば、それを返す
-		if (cachedInitProperty.containsKey(locale)) {
-			if (cachedInitProperty.get(locale).containsKey(mode)) {
-				return PropertyUtil.copy(cachedInitProperty.get(locale).get(mode));
-			}
-		} else {
-			cachedInitProperty.put(locale, new HashMap<Integer, Property>());
-		}
-		
 	    //ファシリティID
 		Property facilityId =
 			new Property(NodeConstant.FACILITY_ID, Messages.getString("facility.id", locale), PropertyConstant.EDITOR_TEXT, DataRangeConstant.VARCHAR_64);
@@ -1290,12 +1280,10 @@ public class NodePropertyUtil {
 		fileSystem.addChildren(fileSystemOID);
 		fileSystem.addChildren(fileSystemType);
 		fileSystem.addChildren(fileSystemDescription);
-		
-		// 初期値をキャッシュに登録（次回から高速化に初期値を取得）
-		cachedInitProperty.get(locale).put(mode, PropertyUtil.copy(property));
-		
+
 		return property;
 	}
+	
 	/**
 	 * プラットフォーム情報（プラットフォームIDおよびプラットフォーム名）を返す。<BR>
 	 * 戻り値は、下記の構成の2次元配列（Object[][]）である。<BR>
@@ -1309,6 +1297,10 @@ public class NodePropertyUtil {
 	 * @return プラットフォーム情報の2次元配列
 	 */
 	private static Object[][] getPlatformNames() {
+		// キャッシュが存在する場合はキャッシュを返す
+		if(platformCache != null){
+			return platformCache;
+		}
 		/** ローカル変数 */
 		Object[][] table = null;
 		//Collection platforms = null;
@@ -1341,7 +1333,7 @@ public class NodePropertyUtil {
 		} catch (RemoteException e) {
 			e.printStackTrace();
 		}
-		
+		platformCache = table;
 		return table;
 	}
 	
@@ -1358,6 +1350,10 @@ public class NodePropertyUtil {
 	 * @return ファシリティ情報の2次元配列
 	 */
 	private static Object[][] getFacilityIdAndFacilityName() {
+		// キャッシュが存在する場合はキャッシュを返す
+		if(facilityIdCache != null){
+			return facilityIdCache;
+		}
 		/** ローカル変数 */
 		Object[][] table = null;
 		ArrayList<NodeInfo> nodes = null;
@@ -1389,7 +1385,7 @@ public class NodePropertyUtil {
 		} catch (RemoteException e) {
 			e.printStackTrace();
 		}
-		
+		facilityIdCache = table;
 		return table;
 	}
 	/**
@@ -1441,7 +1437,6 @@ public class NodePropertyUtil {
 		} catch (RemoteException e) {
 			e.printStackTrace();
 		}
-		
 		return table;
 	}
 	
@@ -1459,6 +1454,10 @@ public class NodePropertyUtil {
 	 * @return 仮想化ソリューション情報の2次元配列
 	 */
 	private static Object[][] getVmSolutionNames() {
+		// キャッシュが存在する場合はキャッシュを返す
+		if(vmSolutionCache != null){
+			return vmSolutionCache;
+		}
 		/** ローカル変数 */
 		Object[][] table = null;
 		ArrayList<RepositoryTableInfo> vmSolutions = null;
@@ -1490,7 +1489,7 @@ public class NodePropertyUtil {
 		} catch (RemoteException e) {
 			e.printStackTrace();
 		}
-		
+		vmSolutionCache = table;
 		return table;
 	}
 	
@@ -1507,6 +1506,10 @@ public class NodePropertyUtil {
 	 * @return 仮想化プロトコル情報の2次元配列
 	 */
 	private static Object[][] getVmProtocol() {
+		// キャッシュが存在する場合はキャッシュを返す
+		if(vmProtocolCache != null){
+			return vmProtocolCache;
+		}
 		/** ローカル変数 */
 		Object[][] table = null;
 		ArrayList<RepositoryTableInfo> vmProtocols = null;
@@ -1535,7 +1538,7 @@ public class NodePropertyUtil {
 		} catch (RemoteException e) {
 			e.printStackTrace();
 		}
-		
+		vmProtocolCache = table;
 		return table;
 	}
 	
