@@ -313,6 +313,8 @@ public class EJBContoroller {
 			RepositoryController repositoryController = null;
 			MonitorSyslogNGController logFilter = null;
 			
+			HashMap<String, HashMap> facilityAttrMapList = new HashMap<String, HashMap>();
+			
 			try{
 				//
 				//ログイン処理
@@ -370,18 +372,29 @@ public class EJBContoroller {
 						}
 							
 						//配下の一覧
-						ArrayList facilityList = repositoryController.getExecTargetFacilityIdList(facilityID);
-						
-						//ノード名/IPアドレス取得
-						ArrayList<String> attributeList = new ArrayList<String>();
-						attributeList.add(FacilityAttributeConstant.NODENAME);
-						attributeList.add(FacilityAttributeConstant.CN);
-						attributeList.add(FacilityAttributeConstant.IPPROTOCOLNUMBER);
-						attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBER);
-						attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBERV6);
-						
-						HashMap facilityAttrMap = repositoryController
-						.getNodeDetail(facilityList, attributeList);
+						HashMap facilityAttrMap = null;
+						if (! facilityAttrMapList.containsKey(facilityID)) {
+							ArrayList facilityList = null;
+							
+							facilityList = repositoryController.getExecTargetFacilityIdList(facilityID);
+							
+							//ノード名/IPアドレス取得
+							ArrayList<String> attributeList = new ArrayList<String>();
+							attributeList.add(FacilityAttributeConstant.NODENAME);
+							attributeList.add(FacilityAttributeConstant.CN);
+							attributeList.add(FacilityAttributeConstant.IPPROTOCOLNUMBER);
+							attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBER);
+							attributeList.add(FacilityAttributeConstant.IPNETWORKNUMBERV6);
+							
+							facilityAttrMap = repositoryController
+							.getNodeDetail(facilityList, attributeList);
+							
+							if (log.isTraceEnabled()) log.trace("facility not found. adding reference. (facilityId = " + facilityID + ")");
+							facilityAttrMapList.put(facilityID, facilityAttrMap);
+						} else {
+							if (log.isTraceEnabled()) log.trace("facility already registered. getting reference. (facilityId = " + facilityID + ")");
+							facilityAttrMap = facilityAttrMapList.get(facilityID);
+						}
 						
 						filterRepInfo.setMap(facilityAttrMap);
 						
@@ -738,29 +751,28 @@ public class EJBContoroller {
 	 * @see #loadFilterInfo()
 	 * @see #sendMsgRetry()
 	 */
-	synchronized private boolean reInitial() {
-		
-		boolean ret = false;
-		
+	private boolean reInitial() {
 		log.info("reInitial() start");
-		
 		_terminate();
 		
-		if (initial()) {
-			
-			log.info("reInitial() success!");
-			ret = true;
-			
-			//エラーフラグ解除
-			setErrFlg(false);
-			
-			loadFilterInfo();
-			sendMsgRetry();
-			
-		} else {
-			log.warn("reInitial() fail!");
+		boolean ret = false;
+		synchronized (this) {
+			if (initial()) {
+				
+				log.info("reInitial() success!");
+				ret = true;
+				
+				//エラーフラグ解除
+				setErrFlg(false);
+				
+				loadFilterInfo();
+				sendMsgRetry();
+				
+			} else {
+				log.warn("reInitial() fail!");
+			}
 		}
-		
+		log.info("reInitial() finish");
 		return ret;
 	}
 	
@@ -768,14 +780,9 @@ public class EJBContoroller {
 	 * 再接続処理を行う
 	 */
 	public void reconnect() {
-		
 		synchronized (reconnectLock) {
-			
 			setErrFlg(true);
-        
-			_terminate();
 		}
-        
 	}
 	
 	/**
